
#ifndef SSHGUARD_LOG_H
#define SSHGUARD_LOG_H

#include <syslog.h>

#define SLOG_SYSLOG     5
#define SLOG_STDERRR    10

int sshguard_log_init();
int sshguard_log(int prio, char *fmt, ...);
int sshguard_log_fin();

#endif

